spacepy.empiricals.getLmax — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- empiricals - module with heliospheric empirical modules »

# spacepy.empiricals.getLmax

`spacepy.empiricals.` `getLmax`(ticks, model='JKemp')

  calculate a simple empirical model for Lmax - last closed drift-shell

  Uses the parametrized Lmax from: Koller and Morley (2010) ‘Magnetopause shadowing effects for radiation belt models during high-speed solar wind streams’ American Geophysical Union, Fall Meeting 2010, abstract #SM13A-1787

  Parameters: | ticks : spacepy.time.Ticktock Ticktock object of desired times model : string, optional ‘JKemp’ (default - empirical model of J. Koller)
  Returns: | out : np.ndarray Lmax - L* of last closed drift shell

  See also

  `spacepy.LANLstar.LANLmax`

  Examples

      >>> from spacepy.empiricals import getLmax
      >>> import spacepy.time as st
      >>> import datetime
      >>> ticks = st.tickrange(datetime.datetime(2000, 1, 1), datetime.datetime(2000, 1, 3), deltadays=1)
      array([ 7.4928412,  8.3585632,  8.6463423])

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- empiricals - module with heliospheric empirical modules »